poets package
=============

Subpackages
-----------

.. toctree::

    poets.grid
    poets.image
    poets.io
    poets.shape
    poets.timedate
    poets.web

Submodules
----------

poets.poet module
-----------------

.. automodule:: poets.poet
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: poets
    :members:
    :undoc-members:
    :show-inheritance:
